// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
// Module: PosWCS
//
// Author: Hassan Siddiqui
//
// Description: 
//
// Reads in X/Y WCS from a given dataset.
//
// If the info in invalid/not present, 
// the valid() method will return false.
//
// Modifications: See ChangeLog
// 
// $Id: PosWCS.h,v 1.2 2012/04/18 09:05:36 eojero Exp $

#ifndef PosWCS_H
#define PosWCS_H

#include <iostream>

/* SAS-specific */
#include "Dal.h"

/* Local classes */
#include "WCSConvertor.h"


class PosWCS
{
public:

  /* Read state from dataset */
  PosWCS( const DataSet * const set,
	  double default_ra,
	  double default_dec,
          double refpa,
          bool useodf );

  /* Destructor */
 ~ PosWCS();

  /* Returns a pointer to WCS object */
  const WCSConvertor * const wcs() const;

  /* Returns the default dec,ra,pa */
  const double refra() const;
  const double refdec() const;
  const double pa() const;

  /* Returns whether to use the ODF for attitude reconstruction */
  const bool useODF() const;

  /* std output contents of PosWCS */
  friend ostream & operator<< (ostream & os, const PosWCS & wcs);

private:

//  bool _valid;

  double _refra;
  double _refdec;
  double _refpa;

  bool _useodf;

  const WCSConvertor * _wcs;
};

#endif
