// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
// Module: SourcePosition
//
// Author: Hassan Siddiqui
//
// Description: 
//
// Stores the coordinates of a point in 2-d space.
//
// Modifications: See ChangeLog
// 
// $Id: SourcePosition.cc,v 1.1 2011/01/11 16:36:10 rsaxton Exp $

/* General */

/* SAS-specific */
#include "SourcePosition.h"
#include "errstr.h"
#include "Tracer.h"

/*** Constructors */
SourcePosition::SourcePosition( double xdet, 
				  double ydet,
				  double theta,
				  double phi) :
  _xdet(xdet),
  _ydet(ydet),
  _theta(theta),
  _phi(phi)
{ 
  PROC;

  errstr << "Constructing SourcePosition object with"
	 << " xdet="<< xdet
	 << " ydet="<< ydet
	 << " theta="<< theta
	 << " phi="<< phi
	 << Sas::message(Msg::App, Msg::Noisy);

  ENDPROC;
}

/*** Accessors */
double SourcePosition::xdet() const
{
  PROC;
  RETURN _xdet;
}
      
double SourcePosition::ydet() const
{
  PROC;
  RETURN _ydet;
}
      
double SourcePosition::theta() const
{
  PROC;
  RETURN _theta;
}
      
double SourcePosition::phi() const
{
  PROC;
  RETURN _phi;
}
      
